.. Copyright (c) 2016, Johan Mabille, Sylvain Corlay and Wolf Vollprecht

   Distributed under the terms of the BSD 3-Clause License.

   The full license is in the file LICENSE, distributed with this software.

xexpression
===========

Defined in ``xtensor/xexpression.hpp``

.. doxygenclass:: xt::xexpression
   :project: xtensor
   :members:

.. doxygenclass:: xt::xshared_expression
   :project: xtensor
   :members:

.. doxygenfunction:: make_xshared
   :project: xtensor

.. doxygenfunction:: share(xexpression<E>&)
   :project: xtensor

.. doxygenfunction:: share(xexpression<E>&&)
   :project: xtensor
